@@ -1,11 +1,12 @@
 # pylint: disable=invalid-name
 """Hold config values"""
+import configparser
 import os
 import os.path
 
-import configparser
 from io import StringIO
 
+
 conf_file = os.path.expanduser(os.path.join("~", ".ptpapi.conf"))
 
 default = """
@@ -22,5 +23,5 @@ findBy=filename,title
 """
 
 config = configparser.ConfigParser()
-config.readfp(StringIO(default))
+config.read_file(StringIO(default))
 config.read(conf_file)
