@@ -1,22 +1,28 @@
 #!/usr/bin/env python
 """Reseed a torrent from PTP, given a path"""
-import sys
-import os
-import os.path
 import argparse
 import logging
-from time import sleep, time
+import os
+import os.path
+import sys
 
+from time import sleep, time
+from urllib.parse import parse_qs, urlparse
+from xmlrpc import client as xmlrpc_client
+from typing import List
+from pathlib import Path
+
+import libtc
 import bencode
+import bencodepy
+
 from pyrosimple import config
 from pyrosimple.util import load_config, metafile, xmlrpc
-from xmlrpc import client as xmlrpc_client
-from urllib.parse import parse_qs, urlparse
 
 import ptpapi
 
 
-class Match(object):
+class Match:
     """A tiny class to make matching easier
 
     Could be expanded to introduce a confidence indicator
@@ -24,10 +30,12 @@ class Match(object):
     ID is an integer-as-a-string, and path is filepath"""
 
     # pylint: disable=too-few-public-methods
-    def __init__(self, ID=None, path=None, matched_files={}):
+    def __init__(self, ID=None, path=None, matched_files=None):
         """A defined match"""
         self.ID = ID
         self.path = path
+        if matched_files is None:
+            matched_files = {}
         self.matched_files = matched_files
 
     def __nonzero__(self):
@@ -42,7 +50,7 @@ class Match(object):
         return "<Match {0}:{1}>".format(self.ID, self.path)
 
 
-def match_by_torrent(torrent, filepath):
+def match_by_torrent(torrent, filepath: str) -> Match:
     """Attempt matching against a torrent ID"""
     logger = logging.getLogger(__name__)
     logger.info(
@@ -51,10 +59,9 @@ def match_by_torrent(torrent, filepath):
         )
     )
 
-    if type(filepath) == bytes:
+    if isinstance(filepath, bytes):
         filepath = filepath.decode("utf-8")
-    assert type(filepath) == str
-    path1 = os.path.abspath(filepath)  # .decode('utf-8')
+    path1 = os.path.abspath(filepath)
     path1_files = {}
     if os.path.isdir(path1):
         for root, _, filenames in os.walk(path1, followlinks=True):
@@ -153,7 +160,7 @@ def match_by_torrent(torrent, filepath):
     return Match(torrent.ID, os.path.dirname(path1), matched_files)
 
 
-def match_by_movie(movie, filepath):
+def match_by_movie(movie, filepath) -> Match:
     """Tries to match a torrent against a single movie"""
     logger = logging.getLogger(__name__)
     logger.info(
@@ -168,14 +175,14 @@ def match_by_movie(movie, filepath):
     return Match(None)
 
 
-def match_by_guessed_name(ptp, filepath, limit, name=None):
+def match_by_guessed_name(ptp, filepath, limit, name=None) -> Match:
     """Use guessit to find the movie by metadata scraped from the filename"""
     logger = logging.getLogger(__name__)
     filepath = os.path.abspath(filepath)
     try:
         import guessit  # pylint: disable=import-error
     except ImportError:
-        logger.warn("Error importing 'guessit' module, skipping name guess")
+        logger.warning("Error importing 'guessit' module, skipping name guess")
         return Match(None)
     logger.info("Guessing name from filepath with guessit")
     if not name:
@@ -197,7 +204,7 @@ def match_by_guessed_name(ptp, filepath, limit, name=None):
     return Match(None)
 
 
-def match_against_file(ptp, filepath, movie_limit):
+def match_against_file(ptp, filepath, movie_limit) -> Match:
     """Use's PTP's file search feature to match a filename to a movie"""
     logger = logging.getLogger(__name__)
     filepath = os.path.abspath(filepath)
@@ -249,7 +256,7 @@ def create_matched_files(match, directory=None, action="hard", dry_run=False):
     return match
 
 
-def load_torrent(ID, path):
+def load_torrent(ID, path, client=None):
     """Send a torrent to rtorrent and kick off the hash recheck"""
     proxy = config.engine.open()
     if proxy is None:
@@ -260,49 +267,36 @@ def load_torrent(ID, path):
     torrent_data = torrent.download()
     data = bencode.bdecode(torrent_data)
     thash = metafile.info_hash(data)
-    try:
-        logger.debug(
-            "Testing for hash {0}".format(proxy.d.hash(thash, fail_silently=True))
-        )
-        logger.error(
-            "Hash {0} already exists in rtorrent as {1}, cannot load.".format(
-                thash, proxy.d.name(thash)
-            )
-        )
-        return False
-    except (xmlrpc_client.Fault, xmlrpc.HashNotFound):
-        pass
-    proxy.load.raw("", xmlrpc_client.Binary(torrent_data))
-    # Wait until the torrent is loaded and available
-    while True:
-        sleep(1)
+    if client is None:
         try:
-            proxy.d.hash(thash, fail_silently=True)
-            break
+            logger.debug(
+                "Testing for hash {0}".format(proxy.d.hash(thash, fail_silently=True))
+            )
+            logger.error(
+                "Hash {0} already exists in rtorrent as {1}, cannot load.".format(
+                    thash, proxy.d.name(thash)
+                )
+            )
+            return False
         except (xmlrpc_client.Fault, xmlrpc.HashNotFound):
             pass
-    logger.info("Torrent loaded at {0}".format(path))
-    proxy.d.custom.set(thash, "tm_completed", str(int(time())))
-    proxy.d.directory.set(thash, path)
-    proxy.d.check_hash(thash)
-    return True
-
-
-def find_existing_torrents(proxy):
-    """Filter out a list of path for all PTP torrents"""
-    paths = []
-    for torrent in proxy.d.multicall(
-        "main", "d.directory=", "d.is_multi_file=", "d.name=", "t.multicall='',t.url="
-    ):
-        basedir, is_multi, name, trackers = torrent
-        for tracker in trackers:
-            if "passthepopcorn" in tracker[0]:
-                # http://rtorrent-docs.readthedocs.io/en/latest/cmd-ref.html#term-d-directory-set
-                if is_multi == 1:
-                    paths.append(basedir)
-                else:
-                    paths.append(os.path.join(basedir, name))
-    return paths
+        proxy.load.raw("", xmlrpc_client.Binary(torrent_data))
+        # Wait until the torrent is loaded and available
+        while True:
+            sleep(1)
+            try:
+                proxy.d.hash(thash, fail_silently=True)
+                break
+            except (xmlrpc_client.Fault, xmlrpc.HashNotFound):
+                pass
+        logger.info("Torrent loaded at {0}".format(path))
+        proxy.d.custom.set(thash, "tm_completed", str(int(time())))
+        proxy.d.directory.set(thash, path)
+        proxy.d.check_hash(thash)
+        return True
+    else:
+        bd = bencodepy.BencodeDecoder()
+        client.add(bd.decode(torrent_data), path)
 
 
 def define_parser():
@@ -344,6 +338,11 @@ def define_parser():
         const=logging.DEBUG,
         default=logging.WARNING,
     )
+    parser.add_argument(
+        "--client",
+        help="Experimental: use a custom libtc URL. See https://github.com/JohnDoee/libtc#url-syntax for examples",
+        nargs=1,
+    )
     parser.add_argument(
         "-v",
         "--verbose",
@@ -392,13 +391,18 @@ def process(cli_args):
     already_loaded = []
     not_found = []
 
-    if args.files == ["-"] or args.files == []:
+    if args.files in (["-"], []):
         filelist = sys.stdin
     else:
         filelist = args.files
 
     loaded_paths = []
 
+    if args.client:
+        client = libtc.parse_libtc_url(args.client[0])
+    else:
+        client = None
+
     for filename in filelist:
         match = Match(None)
         filename = filename.strip("\n")
@@ -480,7 +484,7 @@ def process(cli_args):
             )
             logger.debug("Dry-run: Stopping before actual load")
             continue
-        if load_torrent(match.ID, match.path):
+        if load_torrent(match.ID, Path(match.path), client):
             loaded.append(filename)
         else:
             already_loaded.append(filename)
